summaryrefslogtreecommitdiffhomepage
path: root/packages/browser/src/methods
diff options
context:
space:
mode:
authorMatthew Miller <matthew@millerti.me>2022-07-04 08:01:14 -0700
committerMatthew Miller <matthew@millerti.me>2022-07-04 08:01:14 -0700
commit5a5b5a3bdf7c709493fc9e63f0f02eed99f25baf (patch)
tree3b895f8c273e924dd6fdd52c50fd2528575dc41d /packages/browser/src/methods
parenta0f1a031160584d576fdc7fe16108fa6e3305247 (diff)
Rename supportBrowserAutofill
Diffstat (limited to 'packages/browser/src/methods')
-rw-r--r--packages/browser/src/methods/startAuthentication.ts6
1 files changed, 3 insertions, 3 deletions
diff --git a/packages/browser/src/methods/startAuthentication.ts b/packages/browser/src/methods/startAuthentication.ts
index a568289..7887228 100644
--- a/packages/browser/src/methods/startAuthentication.ts
+++ b/packages/browser/src/methods/startAuthentication.ts
@@ -17,12 +17,12 @@ import { webauthnAbortService } from '../helpers/webAuthnAbortService';
* Begin authenticator "login" via WebAuthn assertion
*
* @param requestOptionsJSON Output from **@simplewebauthn/server**'s generateAssertionOptions(...)
* @param supportBrowserAutofill Initialize conditional UI to enable logging in via browser
* autofill prompts
*/
export async function startAuthentication(
requestOptionsJSON: PublicKeyCredentialRequestOptionsJSON,
- supportBrowserAutofill = false,
+ useBrowserAutofill = false,
): Promise<AuthenticationCredentialJSON> {
if (!browserSupportsWebauthn()) {
throw new Error('WebAuthn is not supported in this browser');
@@ -49,7 +49,7 @@ export async function startAuthentication(
* Set up the page to prompt the user to select a credential for authentication via the browser's
* input autofill mechanism.
*/
- if (supportBrowserAutofill) {
+ if (useBrowserAutofill) {
if (!(await browserSupportsWebAuthnAutofill())) {
throw Error('Browser does not support WebAuthn autofill');
}
@@ -17,12 +17,12 @@ import { webauthnAbortService } from '../helpers/webAuthnAbortService';
*
* @param requestOptionsJSON Output from **@simplewebauthn/server**'s generateAssertionOptions(...)
- * @param supportBrowserAutofill Initialize conditional UI to enable logging in via browser
+ * @param useBrowserAutofill Initialize conditional UI to enable logging in via browser
* autofill prompts
*/